@@ -5,7 +5,7 @@ use strict;
 use ExtUtils::MakeMaker qw(neatvalue);
 use File::Spec;
 
-our $VERSION = '6.63_04';
+our $VERSION = '6.65_01';
 
 require ExtUtils::MM_Any;
 require ExtUtils::MM_Unix;
@@ -84,7 +84,7 @@ $self->{BASEEXT}.def: Makefile.PL
 	system "emximp -o tmpimp$Config::Config{lib_ext} tmpimp.imp" 
 	    and die "Cannot make import library: $!, \$?=$?";
 	# May be running under miniperl, so have no glob...
-	eval "unlink <tmp_imp/*>; 1" or system "rm tmp_imp/*";
+	eval { unlink <tmp_imp/*>; 1 } or system "rm tmp_imp/*";
 	system "cd tmp_imp; $Config::Config{ar} x ../tmpimp$Config::Config{lib_ext}" 
 	    and die "Cannot extract import objects: $!, \$?=$?";      
     }
